<?php

namespace App\Http\Controllers;
use Illuminate\Support\Facades\Storage;
use Illuminate\Http\File;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Settings;
use App\Models\Anuncios;
use App\Models\AnunciosImagens;
use App\Models\Categorias;

class StockController extends Controller
{
  /**
  * Show the application dashboard.
  *
  * @return \Illuminate\Contracts\Support\Renderable
  */
  public function listar($nome)
  {
    $categoria = Categorias::where('nome',$nome)->first();
    if($categoria){
      $settings = Settings::all();
      $anuncios = Anuncios::where('categoria',$categoria->id)->get();
      return view('stock', ['settings' => $settings,'anuncios' => $anuncios,'categoria' => $categoria]);
    }
    return back();
  }


  public function show($id)
  {
    $settings = Settings::all();
    $anuncio = Anuncios::where('uuid',$id)->first();
    if($anuncio){
      return view('detalhe', ['settings' => $settings,'anuncio' => $anuncio]);
    }
    return back();
  }

  public function novo()
  {
    $settings = Settings::all();
    $categorias = Categorias::all();
    return view('anuncio.criar', ['settings' => $settings,'categorias' => $categorias]);
  }

  public function criar(Request $request)
  {
    $uuid = Str::uuid();
    Anuncios::create([
    'uuid' => $uuid,
    'categoria' => $request->input('categoria'),
    'titulo' => $request->input('marca').' '.$request->input('modelo'),
    'descricao' => $request->input('descricao'),
    'preco' => $request->input('preco'),
    'marca' => $request->input('marca'),
    'modelo' => $request->input('modelo'),
    'horas' => $request->input('horas'),
    'cor' => $request->input('cores'), // Changed from 'cor' to 'cores'
    'estado' => $request->input('estado'),
    'ano' => $request->input('mes').'/'.$request->input('ano'),
    'auto_radio' => $request->input('auto_radio'),
    'motor' => $request->input('motor'),
    'modelo_motor' => $request->input('modelo_motor'),
    'combustivel' => $request->input('combustivel'),
    'potencia' => $request->input('potencia'),
    'volume_motor' => $request->input('volume_motor'),
    'numero_cilindros' => $request->input('numero_cilindros'),
    'valvulas' => $request->input('valvulas'),
    'euro' => $request->input('euro'),
    'consumo_combustivel' => $request->input('consumo_combustivel'),
    'tipo_caixa_velocidades' => $request->input('tipo_caixa_velocidades'),
    'velocidades' => $request->input('velocidades'),
    'marca_caixa_velocidades' => $request->input('marca_caixa_velocidades'),
    'deposito_adblue' => $request->input('deposito_adblue'),
    'numero_depositos_combustivel' => $request->input('numero_depositos_combustivel'),
    'volume_depositos' => $request->input('volume_depositos'),
    'eixos' => $request->input('eixos'),
    'configuracao_eixo' => $request->input('configuracao_eixo'),
    'dimensao_pneus' => $request->input('dimensao_pneus'),
    'estado_pneu' => $request->input('estado_pneu'),
    'is_destaque' => $request->has('is_destaque') ? 1 : 0,
    'created_at' => now(),
    'updated_at' => now(),
]);


    // Manipular upload de imagens
    if ($request->hasFile('files')) {
      $arquivos = $request->file('files');
      $contador = 0;

      foreach ($arquivos as $arquivo) {
        $nomeArquivo = $uuid . '-' . $contador;
        $extensao = $arquivo->getClientOriginalExtension();
        $nomeCompleto = $nomeArquivo . '.' . $extensao;

        AnunciosImagens::create([
          'anuncio_uuid' => $uuid,
          'url' => $nomeCompleto,
        ]);

        // Salvar o arquivo com o novo nome
        Storage::putFileAs('/public/files/', $arquivo,$nomeCompleto);

        $contador++;
      }
    }
    return back()->with('success', 'Aunicio criado com sucesso!');;
  }


  public function gerir()
  {
    $anuncios = Anuncios::get();
    $settings = Settings::all();
    $categorias = Categorias::all();
    return view('anuncio.gerir', ['anuncios'=>$anuncios,'settings' => $settings,'categorias' => $categorias]);
  }

  public function destroy($id)
{
    $anuncio = Anuncios::where('uuid',$id)->first();

    foreach ($anuncio->imagens as $img) {
      Storage::delete('/public/files/' . $img->url);

    }
    AnunciosImagens::where('anuncio_uuid',$id)->delete();
    Anuncios::where('uuid',$id)->delete();

    return back()->with('success', 'Anúncio excluído com sucesso!');
}

}
